/**
 * 扩展点类型，默认值为 array，可选值有以下几种：
 * array: 数组形式，支持多值，所有扩展配置都有效；
 * mixin: 混合形式，由多个扩展配置混合形成最后有效的配置；
 * single: 单一对象，只有最后的扩展配置有效
 */
export declare const Type: Readonly<{
    Single: string;
    Mixin: string;
    Multiple: string;
}>;
/**
 * 扩展点声明接口
 */
export interface ExtensionPoint {
    type: string;
    module?: string;
}
/**
 * 扩展配置预处理器接口
 */
export interface Preprocessor {
    /**
     * 扩展配置预处理
     * @param extensions 待处理扩展配置数组
     * @returns 处理后的扩展配置对象，对应于 DefaultExtensionPoint.getExtension() 方法的返回值
     */
    process(extensions: any[], extensionPoint: DefaultExtensionPoint): any;
}
/**
 * 默认的扩展点声明实现类
 */
export declare class DefaultExtensionPoint implements ExtensionPoint {
    readonly type: string;
    module?: string;
    private extensions;
    private extension;
    private preprocessors;
    private processed;
    constructor(point: ExtensionPoint);
    /**
     * 添加扩展
     * @param extensions 扩展配置集合
     */
    addExtension(...extensions: any[]): void;
    /**
     * 获取扩展
     * @returns 当扩展点类型为 Multiple 时，返回扩展配置对象数组；
     *          当扩展点类型为 Single 时，返回最后加入的扩展配置对象；
     *          当扩展点类型为 Mixin 时，返回所有扩展配置对象混合后的结果
     */
    getExtension(): any;
    /**
     * 获取全部扩展配置对象
     */
    getExtensions(): any[];
    /**
     * 添加预处理器
     * @param proprocessors 预处理器集合
     */
    addPreprocessors(...proprocessors: Preprocessor[]): void;
}
